# Quantify & take control of time spent on Discord
## About timecord

time-cord is a library that:
- Tracks time spent on Discord
- Tracks time spent on specific servers & channels

Currently only Mac OS is supported.

#### Areas for improvement:
- Support for non-Mac OS devices

#### Dependencies:
- Pillow
- Easyocr
- tendo
- tzlocal

With the rise of Discord as a platform for teams and friend groups alike, it's important to watch your time management on the platform. There are no current apps specifically for discord time management, so this library aims to fill that gap.  

## Contributing to timecord

If you have suggestions for improving or extending this project, please submit a pull request or issue!

## Installation

This library can be installed through pip: just type the command  ``pip install time-cord``.
